| Century | R Documentation |
Set a Century and Get its Time Interval
Set a Century and Get its Time Interval
An Object of R6Class with methods to set
common time periods and specifications for centuries.
unstruwwel::Periods -> Century
new()Helper function to specify the beginning of a century.
Helper function to specify the middle of a century.
Helper function to specify the end of a century.
Create a century.
Century$new(value)
valueA numerical scalar.
Object of R6Class with methods to set
common time periods and specifications for centuries.
clone()The objects of this class are cloneable with this method.
Century$clone(deep = FALSE)
deepWhether to make a deep clone.
if (interactive()) {
x <- Century$new(15)
x$take(2, type = "third")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.